# Calculator CWL

This is a very basic calculator made using python.

### Installation
```bash
pip install calculator-cwl
            OR
pip3 install calculator-cwl
```

### Usage
```python
from calculator_cwl import Calculator

calc = Calculator()
calc.a = 8
calc.b = 9

print("The sum of 8 & 9 is", calc.add())
print("The difference of 8 & 9 is", calc.subtract())
print("The product of 8 & 9 is", calc.multiply())
print("The quotient after division of 8 by 9 is", calc.divide())
```
**You can also take the user's input and perform the options as per the choice**

### Warning!!!

This is only for demonstration purposes.